@@ -412,7 +412,7 @@ test_that("BackupQueueIndex$push_backup() can push to different directory", {
   bt <- BackupQueueIndex$new(tf, backup_dir = bu_dir)
   bt$push_backup()
 
-  expect_match(bt$backups$dir, "rotor.backups")
+  expect_match(dirname(bt$backups$path), "rotor.backups")
   bt$set_compression(TRUE)
   bt$push_backup()
 
@@ -470,6 +470,21 @@ test_that("BackupQueueIndex: $should_rotate", {
 })
 
 
+
+
+
+test_that("BackupQueueIndex: $should_rotate(verbose = TRUE) displays helpful messages", {
+  tf <- file.path(td, "test")
+  file.create(tf)
+  on.exit(unlink(tf))
+  bq <- BackupQueueIndex$new(tf)
+
+  expect_message(bq$should_rotate(size = "1 tb", verbose = TRUE), "1 TiB")
+  expect_message(bq$should_rotate(size = Inf, verbose = TRUE), "infinite")
+})
+
+
+
 # BackupQueueDatetime -----------------------------------------------------
 context("BackupQueueDateTime")
 
@@ -758,7 +773,7 @@ test_that("BackupQueueDateTime$push_backup() can push to different directory", {
   bt <- BackupQueueDateTime$new(tf, backup_dir = bu_dir)
   bt$push_backup()
 
-  expect_match(bt$backups$dir, "rotor.backups")
+  expect_match(dirname(bt$backups$path), "rotor.backups")
   bt$set_compression(TRUE)
   bt$push_backup()
 
@@ -785,9 +800,44 @@ test_that("BackupQueueDateTime: $should_rotate", {
 })
 
 
+
+
+test_that("BackupQueueDateTime: `age` works with no backups", {
+  tf <- file.path(td, "test")
+  file.create(tf)
+  on.exit(unlink(tf))
+
+  now <- as.Date(as.character(file.info(tf)$ctime))
+  bq <- BackupQueueDateTime$new(tf)
+  expect_false(bq$should_rotate(age = "10 day", now = now, size = 0))
+  expect_true(bq$should_rotate(age = "0 day", now = now, size = 0))
+})
+
+
+
+
+
+test_that("BackupQueueDateTime: $should_rotate(verbose = TRUE) displays helpful messages", {
+  tf <- file.path(td, "test")
+  file.create(tf)
+  on.exit(unlink(tf))
+  bq <- BackupQueueDateTime$new(tf)
+
+  expect_message(bq$should_rotate(age = Inf, size = "1 tb", verbose = TRUE), "age.*size")
+  expect_message(bq$should_rotate(age = 1, size = "1 tb", verbose = TRUE), "size")
+  expect_message(bq$should_rotate(age = "9999 years", size = -1, verbose = TRUE), "9999")
+  expect_message(bq$should_rotate(age = "1000-12-31", size = -1, verbose = TRUE), "1000")
+})
+
+
+
+
 # BackupQueueDate ---------------------------------------------------------
 context("BackupQueueDate")
 
+
+
+
 test_that("BackupQueueDate: $set_max_backups", {
   tf <- file.path(td, "test")
   file.create(tf)
@@ -1049,7 +1099,7 @@ test_that("BackupQueueDateTime$push_backup() can push to different directory", {
   bt <- BackupQueueDate$new(tf, backup_dir = bu_dir)
   bt$push_backup()
 
-  expect_match(bt$backups$dir, "rotor.backups")
+  expect_match(dirname(bt$backups$path), "rotor.backups")
   bt$set_compression(TRUE)
   bt$push_backup()
 
@@ -1114,6 +1164,35 @@ test_that("BackupQueueDate: backups_cache", {
 
 
 
+test_that("BackupQueueDateTime: `age` works with no backups", {
+  tf <- file.path(td, "test")
+  file.create(tf)
+  on.exit(unlink(tf))
+
+  now <- as.Date(as.character(file.info(tf)$ctime))
+  bq <- BackupQueueDate$new(tf)
+  expect_false(bq$should_rotate(age = "10 day", now = now, size = 0))
+  expect_true(bq$should_rotate(age = "0 day", now = now, size = 0))
+})
+
+
+
+
+test_that("BackupQueueDate: $should_rotate(verbose = TRUE) displays helpful messages", {
+  tf <- file.path(td, "test")
+  file.create(tf)
+  on.exit(unlink(tf))
+  bq <- BackupQueueDate$new(tf)
+
+  expect_message(bq$should_rotate(age = Inf, size = "1 tb", verbose = TRUE), "age.*size")
+  expect_message(bq$should_rotate(age = 1, size = "1 tb", verbose = TRUE), "size")
+  expect_message(bq$should_rotate(age = "9999 years", size = -1, verbose = TRUE), "9999")
+  expect_message(bq$should_rotate(age = "1000-12-31", size = -1, verbose = TRUE), "1000")
+})
+
+
+
+
 # cleanup -----------------------------------------------------------------
 
 test_that("BackupQueue: all cleanup succesfull", {
